@@ -630,6 +630,16 @@ void MessageTest::testEmptySubject()
     QVERIFY(msg->subject()->asUnicodeString().isEmpty());
 }
 
+void MessageTest::testReplyHeader()
+{
+    auto msg = readAndParseMail(QStringLiteral("reply-header.mbox"));
+    QVERIFY(msg);
+    QVERIFY(!msg->replyTo(false));
+    QCOMPARE(msg->hasHeader("Reply-To"), false);
+    QCOMPARE(msg->hasHeader("Reply"), true);
+    QVERIFY(msg->headerByType("Reply"));
+}
+
 KMime::Message::Ptr MessageTest::readAndParseMail(const QString &mailFile) const
 {
     QFile file(QLatin1String(TEST_DATA_DIR) + QLatin1String("/mails/") + mailFile);
@@ -646,3 +656,24 @@ KMime::Message::Ptr MessageTest::readAndParseMail(const QString &mailFile) const
     return msg;
 }
 
+void MessageTest::testBug392239()
+{
+    auto msg = readAndParseMail(QStringLiteral("bug392239.mbox"));
+
+    QCOMPARE(msg->subject()->as7BitString().data(), "Subject: ");
+    QCOMPARE(msg->contents().size(), 0);
+    QCOMPARE(msg->contentTransferEncoding()->encoding(), KMime::Headers::CEbase64);
+    QCOMPARE(msg->decodedText().toUtf8().data(), "Following this paragraph there is a double line break which should result in vertical spacing.\r\rPreceding this paragraph there is a double line break which should result in vertical spacing.\r");
+    const QByteArray data = KMime::CRtoLF(msg->decodedText().toUtf8());
+    QCOMPARE(data, "Following this paragraph there is a double line break which should result in vertical spacing.\n\nPreceding this paragraph there is a double line break which should result in vertical spacing.\n");
+}
+
+void MessageTest::testCRtoLF()
+{
+    QByteArray data = "Subject: Test\n";
+    QCOMPARE(CRtoLF(data), "Subject: Test\n");
+    data = "Subject: Test\r";
+    QCOMPARE(CRtoLF(data), "Subject: Test\n");
+    data = "Subject: Test\r\n";
+    QCOMPARE(CRtoLF(data), "Subject: Test\r\n");
+}
